# -*- coding: utf-8 -*-
# Locations of remote files and local directory for cdf files
# You can change data_dir to a directory of your choice
# If you use Linux, Mac or other unix-like system, use data_dir_unix
data_dir = 'C:\\Datapy\\'
data_dir_unix = '~/Datapy/'
themis_remote = 'http://themis.ssl.berkeley.edu/data/themis'
omni_remote = 'https://cdaweb.gsfc.nasa.gov/istp_public/data/omni'
